JsDoc Reference - links

Class Index | File Index

## Classes

- _global_
- links
- links.Filter
- links.Graph3d
- links.Graph3d.Camera
- links.Point2d
- links.Point3d
- links.Slider
- links.StepNumber

# Class links

links bla bla
Defined in: graph3d.js.

Class Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| links()

Method Summary
Method Attributes | Method Name and Description
--- | ---
<static> | links.addEventListener(element, action, listener, useCapture) Add and event listener.
<static> | links.getAbsoluteLeft(elem) Retrieve the absolute left value of a DOM element
<static> | links.getAbsoluteTop(elem) Retrieve the absolute top value of a DOM element
<static> | links.preventDefault(event) Cancels the event if it is cancelable, without stopping further propagation of the event.
<static> | links.removeEventListener(element, action, listener, useCapture) Remove an event listener from an element
<static> | links.stopPropagation(event) Stop event propagation

Class Detail
links()
Method Detail
<static> links.addEventListener(element, action, listener, useCapture)
Add and event listener. Works for all browsers

Parameters:
{DOM Element} element
  An html element
{string} action
  The action, for example "click", without the prefix "on"
{function} listener
  The callback function to be executed
{boolean} useCapture

<static> {number} links.getAbsoluteLeft(elem)
Retrieve the absolute left value of a DOM element

Parameters:
{DOM element} elem
  A dom element, for example a div

Returns:
  {number} left The absolute left position of this element in the browser page.

<static> {number} links.getAbsoluteTop(elem)
Retrieve the absolute top value of a DOM element

Parameters:
{DOM element} elem
  A dom element, for example a div

Returns:
  {number} top The absolute top position of this element in the browser page.

<static> links.preventDefault(event)
Cancels the event if it is cancelable, without stopping further propagation of the event.

Parameters:
event

<static> links.removeEventListener(element, action, listener, useCapture)
Remove an event listener from an element

Parameters:
{DOM element} element
  An html dom element
{string} action
  The name of the event, for example "mousedown"
{function} listener
  The listener function
{boolean} useCapture

<static> links.stopPropagation(event)
Stop event propagation

Parameters:
event

Documentation generated by JsDoc Toolkit 2.3.2 on Tue May 01 2012 16:39:35 GMT+0200 (CEST)